@@ -531,7 +531,7 @@ class VariableClTarget(ReadonlyVariable):
                     'os_install_disk_part', 'os_install_disk_id']
         rootLabel = "{short}-{ver}".format(
             short=self.Get('os_install_linux_shortname'),
-            ver=self.Get('os_install_linux_ver'))
+            ver=self.Get('os_install_linux_build'))
 
         if self.Get('os_install_root_type') == "flash":
             flashLabel = "{short}-{build}".format(
